pub struct RamOnlyStorage {
saved_chunks: AsyncRwLock<FxHashMap<ChunkPos, SimpleRAMChunk>>,
}Expand description
In-memory chunk storage.
This storage implementation doesn’t persist any data to disk. It’s designed for test worlds and minigame worlds:
- It has chunk generation which can be disabled with
EmptyChunkGen - It will save all the data so perfectly for minigames
TODO: Will later have the option to load a world from storage and clone it for easy world handling
Fields
saved_chunks: AsyncRwLock<FxHashMap<ChunkPos, SimpleRAMChunk>>This saves every chunk, and it saves the changes in the world to make it possible to run the server fully in memory
Implementations
Sourceimpl RamOnlyStorage
impl RamOnlyStorage
Sourcepub fn empty_world() -> Self
pub fn empty_world() -> Self
Creates a new RAM-only storage which can be used for minigames, etc.
This should be used for a RAM storage solution of a map and every world generation should be supported
Sourcepub async fn load_chunk(
&self,
pos: ChunkPos,
min_y: i32,
height: i32,
level: Weak<World>,
) -> Result<Option<LoadedChunk>>
pub async fn load_chunk( &self, pos: ChunkPos, min_y: i32, height: i32, level: Weak<World>, ) -> Result<Option<LoadedChunk>>
Loads a chunk from storage.
Sourcepub async fn save_chunk_data(&self, prepared: PreparedChunkSave) -> Result<bool>
pub async fn save_chunk_data(&self, prepared: PreparedChunkSave) -> Result<bool>
Saves prepared chunk data to storage.
Sourcepub async fn chunk_exists(&self, pos: ChunkPos) -> Result<bool>
pub async fn chunk_exists(&self, pos: ChunkPos) -> Result<bool>
Checks if a chunk exists in storage.